bands_hessian_mesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bands_hessian_mesh

property ElectronicBandStructure.bands_hessian_mesh

  Bands hessian mesh is a numpy array that stores each band hessian in a mesh grid. Shape = [n_kx,n_ky,n_kz,n_bands,n_spin,3,3], where the last two dimensions represent d/dx,d/dy,d/dz

  Returns:

    np.ndarray – Bands hessian mesh is a numpy array that stores each band hessian in a mesh grid. Shape = [n_kx,n_ky,n_kzn_bands,n_spin,3,3], where the first and second dimension represent d/dx,d/dy,d/dz